
#ifndef ROOT_TPosixCondition
#define ROOT_TPosixCondition

//+SEQ,CopyRight,T=NOINCLUDE.

//////////////////////////////////////////////////////////////////////////
//                                                                      //
// TPosixCondition                                                      //
//                                                                      //
// This class provides an interface to the posix condition variable     //
// routines.                                                            //
//                                                                      //
//////////////////////////////////////////////////////////////////////////

#ifndef ROOT_TConditionImp
//*KEEP,TConditionImp,T=C++.
#include "TConditionImp.h"
//*KEND.
#endif

#ifndef __CINT__
#include <pthread.h>
#else
//*KEEP,R__pthread,T=C++.
#include "R__pthread.h"
//*KEND.
#endif

class TMutexImp;
class TPosixMutex;


class TPosixCondition : public TConditionImp {

private:
   TPosixMutex    *fMutex;   // mutex used around Wait() and TimedWait()
   pthread_cond_t  fCond;    // the pthread condition variable

public:
   TPosixCondition(TMutexImp *m);
   virtual ~TPosixCondition();

   Int_t  Wait();
   Int_t  TimedWait(ULong_t secs, ULong_t nanoSecs = 0);
   Int_t  Signal();
   Int_t  Broadcast();

ClassDef(TPosixCondition,0)
};

#endif
